@@ -183,22 +183,22 @@ static PyMethodDef ShoutObjectMethods[] = {
     "Update stream metadata on server (takes a dictionary argument. Current keys are: \"song\"" },
 
   /* attributes (cribbed from Arc's ogg-python technique) */
-  { "host", NULL, 0, NULL },
-  { "port", NULL, 0, NULL },
-  { "user", NULL, 0, NULL },
-  { "password", NULL, 0, NULL },
-  { "agent", NULL, 0, NULL },
-  { "format", NULL, 0, NULL },
-  { "protocol", NULL, 0, NULL },
-  { "nonblocking", NULL, 0, NULL },
-  { "mount", NULL, 0, NULL },
-  { "name", NULL, 0, NULL },
-  { "url", NULL, 0, NULL },
-  { "genre", NULL, 0, NULL },
-  { "description", NULL, 0, NULL },
-  { "public", NULL, 0, NULL },
-  { "dumpfile", NULL, 0, NULL },
-  { "audio_info", NULL, 0, NULL },
+  { "host", NULL, METH_NOARGS, NULL },
+  { "port", NULL, METH_NOARGS, NULL },
+  { "user", NULL, METH_NOARGS, NULL },
+  { "password", NULL, METH_NOARGS, NULL },
+  { "agent", NULL, METH_NOARGS, NULL },
+  { "format", NULL, METH_NOARGS, NULL },
+  { "protocol", NULL, METH_NOARGS, NULL },
+  { "nonblocking", NULL, METH_NOARGS, NULL },
+  { "mount", NULL, METH_NOARGS, NULL },
+  { "name", NULL, METH_NOARGS, NULL },
+  { "url", NULL, METH_NOARGS, NULL },
+  { "genre", NULL, METH_NOARGS, NULL },
+  { "description", NULL, METH_NOARGS, NULL },
+  { "public", NULL, METH_NOARGS, NULL },
+  { "dumpfile", NULL, METH_NOARGS, NULL },
+  { "audio_info", NULL, METH_NOARGS, NULL },
   
   /* sentinel */
   { NULL, NULL, 0, NULL }
